@@ -4,7 +4,8 @@ from squyrrel.orm.field import ManyToMany, OneToMany
 from squyrrel.orm.exceptions import RelationNotFoundException
 from squyrrel.sql.join import OnJoinCondition, JoinType
 from squyrrel.sql.utils import sanitize_column_reference, listify
-from squyrrel.orm.filter import ManyToOneFilter, ManyToManyFilter, StringFieldFilter, OrFieldFilter, FieldFilter
+from squyrrel.orm.filter import ManyToOneFilter, ManyToManyFilter, StringFieldFilter, OrFieldFilter, FieldFilter, \
+    BooleanFieldFilter, JunctionType
 from squyrrel.sql.references import ColumnReference
 from squyrrel.orm.model import Model
 from squyrrel.sql.clauses import SelectClause, FromClause, WhereClause, Pagination, OrderByClause
@@ -53,8 +54,7 @@ class QueryBuilder:
 
     def _get_model(self, model: Type[Model] or str):
         if self._qw is not None:
-            print('model:')
-            print(self._qw.get_model(model))
+            # print('model:', self._qw.get_model(model))
             return self._qw.get_model(model)
         return model
 
@@ -96,32 +96,31 @@ class QueryBuilder:
 
     def many_to_one_filter_condition(self, filter: ManyToOneFilter):
         # todo: handle filter.negate
-        conditions = []
-        # print(filter.id_values)
-        for id_value in filter.id_values:
-            conditions.append(
-                Equals.column_as_parameter(
-                    ColumnReference(filter.key, table=self._model.table_name),
-                    id_value
-                )
-            )
-        if conditions:
-            return Or.concat(conditions)
-        return None
+        return Equals.column_as_parameter(
+            ColumnReference(filter.key, table=self._model.table_name),
+            filter.value
+        )
 
     def many_to_many_filter_condition(self, filter: ManyToManyFilter):
         # todo: handle filter.negate
         conditions = []
-        filterforeign_model = self._get_model(filter.foreign_model)
-        for id_value in filter.id_values:
+        filter_foreign_model = self._get_model(filter.foreign_model)
+        for id_value in filter.value:
             conditions.append(
                 Equals.column_as_parameter(
-                    ColumnReference(filter.key, table=filterforeign_model.table_name),
+                    ColumnReference(filter.key, table=filter_foreign_model.table_name),
                     id_value
                 )
             )
         if conditions:
-            return Or.concat(conditions)
+            if len(conditions) > 1:
+                if filter.junction_type == JunctionType.AND:
+                    condition = And.concat(conditions)
+                else:
+                    condition = Or.concat(conditions)
+            else:
+                condition = conditions[0]
+            return condition
         return None
 
     def string_filter_condition(self, filter: StringFieldFilter):
@@ -135,6 +134,12 @@ class QueryBuilder:
                 ColumnReference(filter.key, table=self._model.table_name),
                 search_value=filter.value)
 
+    def boolean_filter_condition(self, filter: BooleanFieldFilter):
+        return Equals.column_as_parameter(
+            ColumnReference(filter.key, table=self._model.table_name),
+            value=filter.value
+        )
+
     def or_filter_condition(self, filter: OrFieldFilter):
         conditions = []
         for filter in filter.filters:
@@ -150,6 +155,8 @@ class QueryBuilder:
             return self.string_filter_condition(filter)
         elif isinstance(filter, OrFieldFilter):
             return self.or_filter_condition(filter)
+        elif isinstance(filter, BooleanFieldFilter):
+            return self.boolean_filter_condition(filter)
         return None
 
     def model_filters(self, filters: List[Type[FieldFilter]]):
@@ -237,6 +244,7 @@ class QueryBuilder:
     def _build_where_clause(self):
         if self._filter_conditions:
             self._where_clause = WhereClause(And.concat(self._filter_conditions))
+            # print(self._where_clause)
         else:
             self._where_clause = None
 
